part of aliyun_player_fluttify;

class AliPlayer extends _PlayerHolder with _PlayerCommunity, _PlayerPro {
  AliPlayer._();

  /// 创建播放器
  static Future<AliPlayer> create() async {
    final result = AliPlayer._();
    await platform(
      android: (pool) async {
        final context = await android_app_Application.get();
        result._androidPlayer = await com_aliyun_player_AliPlayerFactory
            .createAliPlayer__android_content_Context(context);
      },
      ios: (pool) async {
        result._iosPlayer = await ios.AliPlayer.create__();
      },
    );
    return result;
  }
}

mixin _PlayerCommunity on _PlayerHolder {
  /// 设置数据源
  Future<void> setDataSource(SourceBase source) async {
    return platform(
      android: (pool) async {
        if (source is UrlSource) {
          await _androidPlayer
              .setDataSource__com_aliyun_player_source_UrlSource(
            await source.toAndroidModel(),
          );
        } else if (source is VidSts) {
          await _androidPlayer.setDataSource__com_aliyun_player_source_VidSts(
            await source.toAndroidModel(),
          );
        } else if (source is VidAuth) {
          await _androidPlayer.setDataSource__com_aliyun_player_source_VidAuth(
            await source.toAndroidModel(),
          );
        } else if (source is VidMps) {
          await _androidPlayer.setDataSource__com_aliyun_player_source_VidMps(
            await source.toAndroidModel(),
          );
        }
      },
      ios: (pool) async {
        if (source is UrlSource) {
          await _iosPlayer.setUrlSource(await source.toIOSModel());
        } else if (source is VidSts) {
          await _iosPlayer.setStsSource(await source.toIOSModel());
        } else if (source is VidAuth) {
          await _iosPlayer.setAuthSource(await source.toIOSModel());
        } else if (source is VidMps) {
          await _iosPlayer.setMpsSource(await source.toIOSModel());
        }
      },
    );
  }

  /// 准备播放
  Future<void> prepare() async {
    return platform(
      android: (pool) async {
        await _androidPlayer.prepare();
      },
      ios: (pool) async {
        await _iosPlayer.prepare();
      },
    );
  }

  /// 开始播放
  Future<void> start() async {
    return platform(
      android: (pool) async {
        await _androidPlayer.start();
      },
      ios: (pool) async {
        await _iosPlayer.start();
      },
    );
  }

  /// 暂停播放
  Future<void> pause() async {
    return platform(
      android: (pool) async {
        await _androidPlayer.pause();
      },
      ios: (pool) async {
        await _iosPlayer.pause();
      },
    );
  }

  /// 停止播放
  Future<void> stop() async {
    return platform(
      android: (pool) async {
        await _androidPlayer.stop();
      },
      ios: (pool) async {
        await _iosPlayer.stop();
      },
    );
  }

  /// 释放
  ///
  /// 释放后播放器将不可再被使用
  Future<void> release() async {
    return platform(
      android: (pool) async {
        await _androidPlayer.release();
      },
      ios: (pool) async {
        await _iosPlayer.destroy();
      },
    );
  }
}

mixin _PlayerPro on _PlayerHolder {}

class _PlayerHolder {
  com_aliyun_player_AliPlayer _androidPlayer;
  ios.AliPlayer _iosPlayer;

  final _androidPlayerDelegate = _AndroidPlayerDelegate();
  final _iosPlayerDelegate = _IOSPlayerDelegate();
}
