part of aliyun_player_fluttify;

class AliPlayerView extends StatelessWidget {
  const AliPlayerView({
    Key key,
    @required this.player,
    @required this.onViewCreated,
  }) : super(key: key);

  final AliPlayer player;
  final ValueChanged<AliPlayerController> onViewCreated;

  @override
  Widget build(BuildContext context) {
    if (Platform.isAndroid) {
      return android_view_SurfaceViewWidget(
        surfaceCreated: (holder) {
          player._androidPlayer.setDisplay(holder);
        },
        surfaceChanged: (holder, format, width, height) {
          player._androidPlayer.redraw();
        },
        surfaceDestroyed: (holder) {
          player._androidPlayer.setDisplay(null);
        },
        onSurfaceViewCreated: (controller) async {
          if (onViewCreated != null) {
            final holder = await controller.getHolder();
            onViewCreated(AliPlayerController.android(holder));
          }
        },
      );
    } else if (Platform.isIOS) {
      return UIViewWidget(
        onUIViewCreated: (controller) async {
          await player._iosPlayer.set_playerView(controller);
          if (onViewCreated != null) {
            onViewCreated(AliPlayerController.ios(controller));
          }
        },
      );
    } else {
      return Center(child: Text('未实现的平台'));
    }
  }
}

class AliPlayerController {
  AliPlayerController.android(this._androidModel) : this._iosModel = null;

  AliPlayerController.ios(this._iosModel) : this._androidModel = null;

  final android_view_SurfaceHolder _androidModel;
  android_view_SurfaceHolder get surfaceHolder => _androidModel;

  final UIView _iosModel;
  UIView get uiView => _iosModel;
}
