part of aliyun_player_fluttify;

/// 播放器支持4种播放源：VidSts，VidAuth，VidMps，UrlSource。
/// 其中UrlSource是直接的url播放，其余的三种是通过vid进行播放：VidSts，VidAuth点播用户使用；VidMps仅限MPS用户使用。

class SourceBase {
  String coverPath;
  String title;
}

class VidSts extends SourceBase {
  /// 视频vid
  String vid;

  /// 安全token
  String securityToken;

  /// 临时akId
  String accessKeyId;

  /// 临时akSecret
  String accessKeySecret;

  /// 接入区域
  String region;

  Future<com_aliyun_player_source_VidSts> toAndroidModel() async {
    final result = await com_aliyun_player_source_VidSts.create__();

    await result.setVid(vid);
    await result.setSecurityToken(securityToken);
    await result.setAccessKeyId(accessKeyId);
    await result.setAccessKeySecret(accessKeySecret);
    await result.setRegion(region);

    await result.setCoverPath(coverPath);
    await result.setTitle(title);

    return result;
  }

  Future<ios.AVPVidStsSource> toIOSModel() async {
    final result = await ios.AVPVidStsSource.create__();

    await result.set_vid(vid);
    await result.set_securityToken(securityToken);
    await result.set_accessKeyId(accessKeyId);
    await result.set_accessKeySecret(accessKeySecret);
    await result.set_region(region);

    await result.set_coverURL(coverPath);
    await result.set_title(title);

    return result;
  }

  @override
  String toString() {
    return 'VidSts{vid: $vid, securityToken: $securityToken, accessKeyId: $accessKeyId, accessKeySecret: $accessKeySecret, region: $region}';
  }
}

class VidAuth extends SourceBase {
  /// 视频vid
  String vid;

  /// 授权
  String playAuth;

  /// 接入区域
  String region;

  String quality;

  bool forceQuality = false;

  Future<com_aliyun_player_source_VidAuth> toAndroidModel() async {
    final result = await com_aliyun_player_source_VidAuth.create__();

    await result.setVid(vid);
    await result.setPlayAuth(playAuth);
    await result.setRegion(region);
    await result.setQuality(quality, forceQuality);

    await result.setCoverPath(coverPath);
    await result.setTitle(title);

    return result;
  }

  Future<AVPVidAuthSource> toIOSModel() async {
    final result = await AVPVidAuthSource.create__();

    await result.set_vid(vid);
    await result.set_playAuth(playAuth);
    await result.set_region(region);
    await result.set_quality(quality);
    await result.set_forceQuality(forceQuality);

    await result.set_coverURL(coverPath);
    await result.set_title(title);

    return result;
  }

  @override
  String toString() {
    return 'VidAuth{vid: $vid, playAuth: $playAuth, region: $region, quality: $quality, forceQuality: $forceQuality}';
  }
}

class VidMps extends SourceBase {
  String quality;

  bool forceQuality;

  String mediaId;

  /// 安全token
  String securityToken;

  /// 临时akId
  String accessKeyId;

  /// 临时akSecret
  String accessKeySecret;

  /// 接入区域
  String region;

  /// 接入区域
  String playDomain;

  String authInfo;

  String hlsUriToken;

  Future<com_aliyun_player_source_VidMps> toAndroidModel() async {
    final result = await com_aliyun_player_source_VidMps.create__();

    await result.setQuality(quality, forceQuality);
    await result.setMediaId(mediaId);
    await result.setSecurityToken(securityToken);
    await result.setAccessKeyId(accessKeyId);
    await result.setAccessKeySecret(accessKeySecret);
    await result.setRegion(region);
    await result.setPlayDomain(playDomain);
    await result.setAuthInfo(authInfo);
    await result.setHlsUriToken(hlsUriToken);

    await result.setCoverPath(coverPath);
    await result.setTitle(title);

    return result;
  }

  Future<AVPVidMpsSource> toIOSModel() async {
    final result = await AVPVidMpsSource.create__();

    await result.set_quality(quality);
    await result.set_forceQuality(forceQuality);
    await result
        .initWithVid_accId_accSecret_stsToken_authInfo_region_playDomain_mtsHlsUriToken(
      mediaId,
      accessKeyId,
      accessKeySecret,
      securityToken,
      authInfo,
      region,
      playDomain,
      hlsUriToken,
    );

    await result.set_coverURL(coverPath);
    await result.set_title(title);

    return result;
  }
}

class UrlSource extends SourceBase {
  UrlSource(this.uri);

  final String uri;

  Future<com_aliyun_player_source_UrlSource> toAndroidModel() async {
    final result = await com_aliyun_player_source_UrlSource.create__();

    await result.setUri(uri);
    await result.setCoverPath(coverPath);
    await result.setTitle(title);

    return result;
  }

  Future<AVPUrlSource> toIOSModel() async {
    final result = await AVPUrlSource.create__();

    await result.urlWithString(uri);
    await result.set_coverURL(coverPath);
    await result.set_title(title);

    return result;
  }

  @override
  String toString() {
    return 'UrlSource{uri: $uri}';
  }
}
