part of aliyun_player_fluttify;

class _AndroidPlayerDelegate extends java_lang_Object
    with
        _PlayerCallback,
        com_aliyun_player_IPlayer_OnCompletionListener,
        com_aliyun_player_IPlayer_OnErrorListener,
        com_aliyun_player_IPlayer_OnPreparedListener,
        com_aliyun_player_IPlayer_OnRenderingStartListener,
        com_aliyun_player_IPlayer_OnVideoSizeChangedListener,
        com_aliyun_player_IPlayer_OnLoadingStatusListener,
        com_aliyun_player_IPlayer_OnSeekCompleteListener,
        com_aliyun_player_IPlayer_OnSnapShotListener {
  @override
  Future<void> onCompletion() async {
    if (_onPlayCompletion != null) {
      _onPlayCompletion();
    }
  }

  @override
  Future<void> onError(com_aliyun_player_bean_ErrorInfo var1) async {
    if (_onPlayError != null) {
      _onPlayError(await ErrorInfo.android(var1));
    }
  }

  @override
  Future<void> onPrepared() async {
    if (_onPlayPrepared != null) {
      _onPlayPrepared();
    }
  }

  @override
  Future<void> onRenderingStart() async {
    if (_onRenderingStart != null) {
      _onRenderingStart();
    }
  }

  @override
  Future<void> onVideoSizeChanged(int var1, int var2) async {
    if (_onVideoSizeChanged != null) {
      _onVideoSizeChanged(var1, var2);
    }
  }

  @override
  Future<void> onLoadingBegin() async {
    if (_onLoadingBegin != null) {
      _onLoadingBegin();
    }
  }

  @override
  Future<void> onLoadingEnd() async {
    if (_onLoadingEnd != null) {
      _onLoadingEnd();
    }
  }

  @override
  Future<void> onSeekComplete() async {
    if (_onSeekComplete != null) {
      _onSeekComplete();
    }
  }

  @override
  Future<void> onSnapShot(
    android_graphics_Bitmap var1,
    int var2,
    int var3,
  ) async {
    if (_onSnapshot != null) {
      _onSnapshot(await var1.data, var2, var3);
    }
  }
}

class _IOSPlayerDelegate extends NSObject with _PlayerCallback, AVPDelegate {
  @override
  Future<void> onPlayerEvent_eventType(
    ios.AliPlayer player,
    ios.AVPEventType eventType,
  ) async {
    switch (eventType) {
      case AVPEventType.AVPEventPrepareDone:
        if (_onPlayPrepared != null) {
          _onPlayPrepared();
        }
        break;
      case AVPEventType.AVPEventAutoPlayStart:
        // TODO: Handle this case.
        break;
      case AVPEventType.AVPEventFirstRenderedStart:
        if (_onRenderingStart != null) {
          _onRenderingStart();
        }
        break;
      case AVPEventType.AVPEventCompletion:
        if (_onPlayCompletion != null) {
          _onPlayCompletion();
        }
        break;
      case AVPEventType.AVPEventLoadingStart:
        if (_onLoadingBegin != null) {
          _onLoadingBegin();
        }
        break;
      case AVPEventType.AVPEventLoadingEnd:
        if (_onLoadingEnd != null) {
          _onLoadingEnd();
        }
        break;
      case AVPEventType.AVPEventSeekEnd:
        if (_onSeekComplete != null) {
          _onSeekComplete();
        }
        break;
      case AVPEventType.AVPEventLoopingStart:
        // TODO: Handle this case.
        break;
    }
  }

  @override
  Future<void> onError_errorModel(
    ios.AliPlayer player,
    AVPErrorModel errorModel,
  ) async {
    if (_onPlayError != null) {
      _onPlayError(await ErrorInfo.ios(errorModel));
    }
  }

  @override
  Future<void> onVideoSizeChanged_width_height_rotation(
    ios.AliPlayer player,
    int width,
    int height,
    int rotation,
  ) async {
    if (_onVideoSizeChanged != null) {
      _onVideoSizeChanged(width, height);
    }
  }

  // TODO on snapshot
}

mixin _PlayerCallback {
  VoidCallback _onLoadingBegin;
  VoidCallback _onLoadingEnd;
  VoidCallback _onPlayPrepared;
  VoidCallback _onPlayCompletion;
  VoidCallback _onRenderingStart;
  VoidCallback _onSeekComplete;
  ValueChanged<ErrorInfo> _onPlayError;
  void Function(int width, int height) _onVideoSizeChanged;
  void Function(Uint8List imageData, int width, int height) _onSnapshot;
}
